@@ -4,5 +4,6 @@ from .graph import (NodeGraph,
                     EVT_GSNODEGRAPH_NODESELECT, 
                     EVT_GSNODEGRAPH_NODEDISCONNECT,
                     EVT_GSNODEGRAPH_NODECONNECT,
-                    EVT_GSNODEGRAPH_MOUSEZOOM)
+                    EVT_GSNODEGRAPH_MOUSEZOOM,
+                    EVT_GSNODEGRAPH_ADDNODEBTN)
 from .node import NodeBase, NodeSocket, NodeWire
