@@ -46,8 +46,8 @@ class NodeBase(object):
 
         self._isoutput = False
         self._label = ""
-        self._category = "DEFAULT"
-        self._headercolor = wx.Colour(NODE_HEADER_CATEGORY_COLORS["DEFAULT"])
+        self._category = "INPUT"
+        self._headercolor = wx.Colour(NODE_HEADER_CATEGORY_COLORS["INPUT"])
 
         self._thumbnail = self._CreateEmptyBitmap()
         self._expandicon_bmp = ICON_IMAGE.GetBitmap()
@@ -293,6 +293,15 @@ class NodeBase(object):
         self._expandedsize = wx.Size(NODE_DEFAULT_WIDTH, calc_height)
         self.SetSize(self._expandedsize)
 
+    def FindSocket(self, idname):
+        """ Return the node socket with the given name.
+        :param idname: the socket idname as a string
+        :returns: Socket object
+        """
+        for socket in self.GetSockets():
+            if socket._idname == idname:
+                return socket
+
     def Draw(self, dc) -> None:
         x, y = self.GetPosition()
         w, h = self.GetSize()
